哈利·波特与死亡圣器(上) (豆瓣)
Description: 哈利·波特与死亡圣器(上)电影简介和剧情介绍,哈利·波特与死亡圣器(上)影评、图片、预告片、影讯、论坛、在线购票
Keywords: 哈利·波特与死亡圣器(上),Harry Potter and the Deathly Hallows: Part 1,哈利·波特与死亡圣器(上)影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.244豆瓣电影Top250

# 哈利·波特与死亡圣器(上) Harry Potter and the Deathly Hallows: Part 1 (2010)

导演: 大卫·叶茨
编剧: 史蒂夫·克洛夫斯 / J. K. 罗琳
主演: 丹尼尔·雷德克里夫 / 艾玛·沃森 / 鲁伯特·格林特 / 海伦娜·伯翰·卡特 / 拉尔夫·费因斯 / 比尔·奈伊 / 约翰·赫特 / 艾伦·瑞克曼 / 艾美达·斯丹顿 / 费奥纳·肖 / 邦妮·怀特 / 朱丽·沃特斯 / 米歇尔·费尔利 / 杰米·坎贝尔·鲍尔
类型: 奇幻 / 冒险
制片国家/地区: 英国 / 美国
语言: 英语
上映日期: 2010-11-19(中国大陆/英国)
片长: 146分钟
又名: 哈利波特7：死神的圣物1(港/台) / 哈利·波特与死圣(上) / 哈7(上)
IMDb: tt0926084
豆瓣评分
引用
8.5
528448人评价
5星
42.0%
4星
42.0%
3星
14.5%
2星
1.2%
1星
0.3%
好于 96% 奇幻片
好于 96% 冒险片
想看 看过
评价:
推荐

## 哈利·波特与死亡圣器(上)的剧情简介 · · · · · ·

《哈利·波特与死亡圣器》小站 http://site.douban.com/108361/
邓不利多死后，伏地魔（Ralph Fiennes 饰）与食死徒入侵魔法学校，魔法部也被伏地魔的爪牙操控，邪恶的阴云笼罩魔法世界上空。在哈利·波特（丹尼尔·雷德克里夫 Daniel Radcliffe 饰）17岁生日之际，凤凰社成员及一众好友护送他回到了凤凰社的据点陋居，然而这立即遭到食死徒毁灭性地打击。哈利和罗恩（鲁伯特·格林特 Rupert Grint 饰）、赫敏（爱玛·沃特森 Emma Watson 饰）侥幸逃亡，并且按照邓不利多的嘱托继续寻找伏地魔的魂器。死亡的威胁时刻逡巡左右，他们还要面对友情的考验。在寻找摧毁魂器方法的过程中，死亡圣器的面纱也渐渐揭开。
与此同时，为了置哈利于死地，伏地魔也在寻找最后一件死亡圣器。最后的决战即将到来…… ©豆瓣

## 哈利·波特与死亡圣器(上)的演职员 · · · · · · ( 全部 100 )

- 大卫·叶茨 导演
- 丹尼尔·雷德克里夫 演员
- 艾玛·沃森 饰 赫敏·格兰杰
- 鲁伯特·格林特 演员
- 海伦娜·伯翰·卡特 演员
- 拉尔夫·费因斯 演员

## 哈利·波特与死亡圣器(上)的视频和图片 ······ ( 预告片1 | 添加视频评论 | 图片1085 · 添加 )

## 哈利·波特与死亡圣器(上)的获奖情况 · · · · · · ( 全部 )

- 第83届奥斯卡金像奖
- 最佳视觉效果(提名)
- 约翰·理查森 / 克里斯蒂安·曼兹 / 蒂姆·伯克 / 尼古拉斯·阿萨迪

- 第20届MTV电影奖
- MTV电影奖 年度电影(提名)

- 第12届美国电影学会奖
- 特别表彰

## 喜欢这部电影的人也喜欢 · · · · · ·

  哈利·波特与凤凰社

  神奇动物在哪里

  加勒比海盗2：聚魂棺

  霍比特人1：意外之旅

  指环王1：护戒使者

  查理和巧克力工厂

  少年派的奇幻漂流

  奇异博士

  头号玩家

  本杰明·巴顿奇事

我要写短评

## 哈利·波特与死亡圣器(上)的短评 · · · · · · ( 全部 76229 条 )

热门 / 最新 / 好友

### 1668 有用 Mumu 看过 2010-11-19 15:21:13

火车被搜查时那个男孩儿说my father will hear about this，如果是字幕组一定会翻译成我爸是李刚吧……

### 972 有用 Q。 看过 2010-11-19 03:02:40

没看过原著的人可能会被不少人名弄混淆。色调是越来越暗，整个电影就是无尽的奔跑，除了中间部分略有拖沓，上下部分节奏控制得很好。电影中零星出现的笑点总是能逗得整个影院哄堂大笑，特别是哈里与赫敏在帐篷那段舞蹈尤为打动人。Btw，死亡圣器的那段童话故事的皮影戏个人觉得十分有意思。★★★★

### 1289 有用 卡卡卡 看过 2010-11-18 20:45:09

当哈利深情望着赫敏搂着她在帐篷里翩翩起舞时，当赫敏倚在哈利肩头用温柔的声音道圣诞快乐时，当哈利和赫敏赤裸相拥在冰河上贴身激吻时，我怒从心起！！导演你少拍点奸情戏会死会死啊！！！仍然给5星，为赫敏的颜。

### 1129 有用 D I D A 看过 2010-11-19 23:32:34

如果不是最完美，也是最完整。当血染半身的罗恩用黑色的眼眶爆发出演技的光彩，当缱绻伤怀的赫敏跳着平凡简单的舞步面对贝拉的折磨，当哈利收起小天狼星的相框面对双亲的坟墓呢喃道：Merry christmas，当小精灵多比满噙泪水躺在“朋友”的怀中沉睡……这场成人礼，即使沉重也足够完满。

### 132 有用 Xenophilius 看过 2010-11-18 02:13:33

一开始就给了个悲情的基调 看得难受但却很像看完 大概是看完书太久 很多情节都不记得了 这部比起之前的 大家的演技都大涨呀

> 更多短评 76229条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 哈利·波特与死亡圣器(上)的影评 · · · · · · ( 全部 935 条 )

热门 / 最新 / 好友
萌神小琪琪 2010-11-19 23:49:16

## 导演你到底是有多想要罗恩和赫敏在一起啊！！！

本来想在标题里加上【剧透慎入】的，不过想想像《哈利波特》这种小说改编的电影大家都被原著透得差不多了也就无所谓了吧，什么？你没看过小说？这样也算哈迷吗？！！ 看完电影我非常激动，回来查了查，死亡圣器（上）的导演竟然跟混血王子和凤凰社的导演是同一个人，把混血王... (展开)
1187 60 276回应 收起
strawland 2010-11-20 02:47:12

## 十年的光球

十年前我在新华书店看到《哈利波特与魔法石》这本书的时候，我没有记错的话那时卖十九块五，用我仅有的二十块钱买的，并且绝对是偶然，因为当时“这本书从上到下没有吸引我的地方”。即使是现在看来，我想到这十九块五时，仍然觉得那是我花钱花得最值的一次，很大程度上说，这... (展开)
1107 64 207回应 收起
远近 2010-11-19 20:56:13

## 有关段子，有关麻瓜（很剧透！！）

这篇影评可能有剧透

下午和朋友去看了哈7，我应该是忠实的哈迷——哦对——我是可以这么说，要知道，对一件事情说忠实的崇拜应该是一件比较难的事情。对于哈利波特，我觉得我可以这么形容自己，不仅仅是书、电影、正版碟，还有各种原单周边，比如我就在淘宝上代沟过哈利波特的魔杖，装模作样念一些... (展开)
502 43 160回应 收起
辰晨 2010-11-18 11:54:32

## 前情扼要 V3.3

这篇影评可能有剧透

介于最后一部与之前关联比较大，为了让大家看的不那么一头雾水，我尽量把主线都给叙述了一下。觉得长可以直接拉到你想看的部分。有啥问题和建议以及别字可以留言，谢谢。 * 写完之后我又看了一遍电影。现在觉得原著连贯性太强了，写的时候游走在遗漏主线和剧透的边缘，不能过分... (展开)
398 11 104回应 收起
风息神泪 2010-11-25 13:24:50

## 《哈利.波特7》：枪战精彩，童话结束

做为一个并不死忠的原著读者，虽然买过全套，《哈利波特》也只记得住前四本的内容，后面几本，唯二记得的重点情节：就是邓布利多死了，以及斯内普跟煎鱼一样反来反去的上演着KING OF无间道。 这点导致了我看《哈利波特7：上》的电影时，经常对屏幕展现一种夕阳红追忆逝水年... (展开)
302 91 154回应 收起
逍遥兽 2010-11-22 12:27:11

## 天地大，蜉蝣身小，少年子弟江湖老

推荐理由：阴郁的哥特范儿仍在，却也未忘抒情，张弛有度，跌宕有致。这么多部哈利•波特，难得这一部，拍得最从容。 片 名：《哈利•波特与死亡圣器（上）》 导 演：大卫•叶茨 主 演：丹尼尔•雷德克里夫，艾玛•沃特森，鲁伯特•格林特，海伦娜•... (展开)
177 6 36回应 收起
清千岁 2010-11-21 02:20:29

## 这样改，你是真的读懂《哈利·波特》了吗

打了4星，首先因为这是一部《哈利·波特》，再有这一部确实比之前的《混血王子》有长进，但我还是无法忽视其中的问题，而且这个问题还挺严重，那就是导演大卫·耶茨的自由发挥未免太多了，以至于让人怀疑他是否真的读懂了《哈利·波特》。 列举几条我眼中很不妥的改动，因为... (展开)
204 11 41回应 收起
茄子酱 2010-11-20 09:07:21

## 一段关于爱和人无完人的成长

这篇影评可能有剧透

相信很多观众都和我一样，与哈利波特一起走过了十年。就像《霜与火》里对时间的描述一样：“诞生快得像钢刀的利刃，孩提好似白驹过隙，青春就像电光一闪，壮年犹如南柯一梦，中年无疑是荒诞的神话，风烛残年转瞬即逝，死亡是最后的必然归宿。”十年，当我坐在电影院靠椅上那一... (展开)
76 4 29回应 收起
张小北 2010-11-23 21:57:00

## 最后高潮的前戏准备

作为一个看过每一部“哈利波特”系列电影但又非书迷的观众，我现在对大卫·叶茨（David Yates）这个导演已经陷入了“斯德哥尔摩综合症”的状态中。虽然我一直不喜欢这位导演执导的三部“哈利波特”电影（凤凰社、混血王子和半部死亡圣器），但也不得不佩服这位一直在书迷... (展开)
46 7 25回应 收起
李大米 2010-11-20 18:15:40

## 以此纪念Harry Potter里最纯净的生灵，Dobby⋯⋯

这篇影评可能有剧透

今天去看了哈7第一部，一口气看了两遍，之后的滋味，久久难以平抚，比前几天看Due Date时候看到哈7预告片的时候更加复杂。终于，走到这里了，只有一步，又是一个终结。 朋友说，这种感觉很奇妙，奇妙的就像许多年前第一次看哈利波特的时候，绝对没有想到，走到最后的时候，是... (展开)
67 16回应 收起

> 更多影评 935篇

添加新讨论

## 讨论区 · · · · · ·

海德薇死了吗 | 来自这样不好 | 3 回应 | 2022-11-24 06:32:24
德拉科这个反派有点让人心疼 | 来自告白；龙哥 | 1 回应 | 2022-11-14 22:01:22
有没有人超级喜欢里面的那个动画？ | 来自三天 | 23 回应 | 2022-10-29 22:41:27
伏地魔有1000个机会杀si哈利，但我就是玩儿，美其... | 来自红孩儿 | 2 回应 | 2022-10-20 02:26:35
The chosen one? | 来自CAPTAIN |  | 2022-10-15 16:44:21

> 去这部影片的讨论区（全部241条）

## 关于《哈利·波特与死亡圣器(上)》的问题 · · · · · · ( 全部7个 )

- 为什么马尔福庄园里马尔福的爸爸和贝拉特里克斯没认出来哈利？ 1人回答
- 为什么一个问题都没有？ 2人回答

> 全部7个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 优酷视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- {北美电影票房总排行} (荔枝超人)
- 电影中的美少年 (海棠一生)
- ★豆瓣高分电影榜★ （中）8.5-8.3分 (影志)
- 第83届奥斯卡+第68届金球奖 获奖/候选影片 (影志)
- 【2010年国内公映电影排期】 (荔枝超人)

## 谁在看这部电影 · · · · · ·

- 豆友AnE4cEL3Ho
  刚刚 看过
- momo
  3分钟前 看过
- Edric
  4分钟前 看过

1078482人看过 / 46584人想看

订阅哈利·波特与死亡圣器(上)的评论:
feed: rss 2.0